//
//  SENTConfig.h
//  SENTSDK
//
//  Created by Gustavo Nascimento on 28/07/17.
//  Copyright © 2018 Sentiance. All rights reserved.
//

@import Foundation;
@class SENTSDKStatus;
#import "SENTMetaUsersLinker.h"


@interface SENTConfig : NSObject 

/** @brief App ID created and managed by Sentiance's Developer Dashboard */
@property (nonatomic, strong) NSString *appId;

/** @brief Secret token created along with App ID */
@property (nonatomic, strong) NSString *secret;

/** @brief Configuration check on trip trigger availability */
@property (nonatomic, assign) BOOL isTriggeredTrip;

/** @brief Set the platform base URL */
@property (nonatomic, strong) NSString *baseURL;

/** @brief Key value pair passed from [AppDelegate application:application didFinishLaunchingWithOptions:launchOptions] */
@property (nonatomic, strong) NSDictionary *launchOptions;

/** @brief App ID created and managed by Sentiance's Developer Dashboard */
@property (nonatomic, copy) void (^didReceiveSdkStatusUpdate)(SENTSDKStatus *issue);
@property (nonatomic, copy) MetaUserLinker link;

/** @brief Enables the detection of hard events */
@property (nonatomic, assign) BOOL isHardEventDetectionEnabled __deprecated;

/**
 SDK configuration initialization method. Returned SENTConfig object is passed to [SENTSDK initWithConfig].
 @param appId application key which you get from Sentiance account
 @param secret secret key which you get from Sentiance account
 @param launchOptions A dictionary indicating the reason the app was launched (if any). The contents of this dictionary may be empty in situations where the user launched the app directly. For information about the possible keys in this dictffffionary and how to handle them, see Launch Options Keys.

 */
- (id)initWithAppId:(NSString *)appId secret:(NSString *)secret launchOptions:(NSDictionary *)launchOptions;


/**
 SDK config intialization method with linking to customer's user id. It creates a continuous Sentiance profile across application installations and re-installations on different devices, linked together by their own user_id.
 @param appId application key which you get from Sentiance account
 @param secret secret key which you get from Sentiance account
 @param link MetaUsersLinker type block which returns linkSuccess or linkFailed depended on how linking gone. Use InstallId to link with backend.
 @param launchOptions A dictionary indicating the reason the app was launched (if any). The contents of this dictionary may be empty in situations where the user launched the app directly. For information about the possible keys in this dictionary and how to handle them, see Launch Options Keys.
 */
- (id)initWithAppId:(NSString *)appId secret:(NSString *)secret link:(MetaUserLinker)link launchOptions:(NSDictionary *)launchOptions;

- (BOOL)isValidConfig;

@end
